@@ -3,7 +3,7 @@ from pathlib import Path
 from slugify import slugify
 from watchdog.events import RegexMatchingEventHandler
 
-from kart.miners import DefaultMarkdownMiner
+from kart.miners import DefaultMarkupMiner
 from kart.utils import KartDict
 
 try:
@@ -20,11 +20,11 @@ from jinja2.runtime import Context
 from mistune.directives import Directive
 
 from kart.mappers import Mapper
-from kart.markdown import KartMistuneRenderer, TocRenderer
+from kart.ext.markdown import KartMistuneRenderer, TocRenderer
 from kart.utils import KartObserver
 
 
-class DefaultDocumentationMiner(DefaultMarkdownMiner):
+class DefaultDocumentationMiner(DefaultMarkupMiner):
     """Miner that recursively looks for data in the ``docs`` folder"""
 
     def __init__(self, directory: str = "docs"):
